Learn R Programming

sporm (version 1.1.1)

confid.int.theta: Confidence interval of the proportionality parameter

Description

Confidence interval of the proportionality parameter \(\theta\) of the proportional odds rate model

Usage

confid.int.theta(x, y, method = c("chi-sq", "simulate"), 
    conf.level = 0.95, grd = 0.001, B = 1000,  
    tol = 1e-07, maxit = 500)

Arguments

x,y

Vectors containing the data values of the two samples \(x_1,\ldots,x_m\) and \(y_1,\ldots,y_n\).

method

A character string specifying the alternative hypothesis, must be one of "chi-sq" (default), "simulate". You can specify just the initial letter.

conf.level

Confidence level of the interval.

grd

Increment of the grid of points for searching the end-points of the interval

B

Number of Monte Carlo trials for approximating the critical values using simulation approach

tol

Convergence tolerance used in the Newton iteration

maxit

The maximum number of Newton iterations.

Value

theta.L

Lower confidence bound

theta.U

Upper confidence bound

theta.hat

Maximum rank-based likelihood estimate of theta

C.alpha

Critical value

%% ...

Details

See the reference below.

References

Zhong Guan and Cheng Peng (2011), "A rank-based empirical likelihood approach to two-sample proportional odds model and its goodness-of-fit", Journal of Nonparametric Statistics, to appear.

See Also

mrle.sporm.

Examples

Run this code
# NOT RUN {
# Radar tube life data
z<-RadarTube$Days
v<-RadarTube$Type
x<-z[v==1]; y<-z[v==2]
confid.int.theta(x, y, conf.level=.95, grd = 0.01, B=100)
confid.int.theta(x, y, method= "simulate", conf.level=.95, grd = 0.01, B=100)
# }

Run the code above in your browser using DataLab