Calculates the profile loglikelihood \(\ell(\theta)\) on interval \((\theta_1,\theta_2)\) which contains the maximum rank-based likelihood estimate \(\hat\theta\)
ell.theta(x, y, theta.hat, p.hat, theta1, theta2, n.theta = 40,
tol = 1e-07, maxit = 500)Vectors containing the data values of the two samples \(x_1,\ldots,x_m\) and \(y_1,\ldots,y_n\).
Maximum rank-based likelihood estimate of theta
Maximum rank-based likelihood estimate of p
Left and right end-points of the interval on which the profile loglikelihood is calculated
number of theta values in the above interval on which the profile loglikelihood is calculated
Convergence tolerance used in the Newton iteration
The maximum number of Newton iterations.
the profile loglikelihood
the interval on which the profile loglikelihood is calculated
See the reference below.
Zhong Guan and Cheng Peng (2011), "A rank-based empirical likelihood approach to two-sample proportional odds model and its goodness-of-fit", Journal of Nonparametric Statistics, to appear.