Learn R Programming

sporm (version 1.1.1)

ks.sporm: KS test for the semiparametric proportional odds rate model

Description

Goodness-of-fit test of Kolmogorov-Smirnov type for the semiparametric proportional odds rate model

Usage

ks.sporm(x, y, B = 1000)

Arguments

x, y

Vectors containing the data values of the two samples \(x_1,\ldots,x_m\) and \(y_1,\ldots,y_n\).

B

The number of Monte Carlo trials for simulation approach.

Value

ks

The Kolmogorov-Smirnov type test statistic.

pval

The p-value of the KS test.

%% ...

Details

Using the Monte Carlo simulation method to approximate the p-vakue of the KS test statistic which is distribution-free and is calculate by internal function ks.stat.

References

Zhong Guan and Cheng Peng (2011), "A rank-based empirical likelihood approach to two-sample proportional odds model and its goodness-of-fit", Journal of Nonparametric Statistics, to appear.

See Also

ks.stat, mrle.sporm.

Examples

Run this code
# NOT RUN {
# Radar tube life data
z<-RadarTube$Days
v<-RadarTube$Type
x<-z[v==1]; y<-z[v==2]
## K-S goodness-of-fit test
ks.sporm(x,y,  B=100)
# }

Run the code above in your browser using DataLab