Learn R Programming

sporm (version 1.1.1)

mrle.sporm: Semiparametric proportional odds rate model.

Description

Maximum rank-based likelihood estimates of the proportionality parameter \(\theta\) and probability masses of the discretized baseline distribution \(F\).

Usage

mrle.sporm(x, y, theta = 1, p = rep(1/(length(x) + length(y)), 
    length(x) + length(y)), tol = 1e-07, maxit = 50)

Arguments

x, y

Vectors containing the data values of the two samples \(x_1,\ldots,x_m\) and \(y_1,\ldots,y_n\).

theta

Initial value for proportionality parameter \(\theta\).

p

Initial value for probability masses \(p_1,\ldots,p_N\) of the discretized baseline distribution \(F\).

tol

Convergence tolerance used in the Newton iteration

maxit

The maximum number of Newton iterations.

Value

theta

The maximum rank-based likelihood estimate of the proportionality parameter \(\theta\).

p

The maximum rank-based likelihood estimate of probability masses \(p_1,\ldots,p_N\) of the discretized baseline distribution \(F\).

ell

The maximum rank-based loglikelihood.

del

Convergent tolerance which is sum of the absolute scores, and absolute changes of the parameters theta and p.

Details

The Newton iteration method is applied to find the maximum rank-based likelihood estimates of the proportionality parameter \(\theta\) and probability masses \(p_1,\ldots,p_N\) of the discretized baseline distribution \(F\). If the default initial values for theta and/or p do not work, functions newton.theta, dd.est and phi can be used to calculate other initials.

References

Zhong Guan and Cheng Peng (2011), "A rank-based empirical likelihood approach to two-sample proportional odds model and its goodness-of-fit", Journal of Nonparametric Statistics, to appear.

Examples

Run this code
# NOT RUN {
# Use radar tube life data
z<-RadarTube$Days
v<-RadarTube$Type
x<-z[v==1]; y<-z[v==2]
# Dabrowska-Doksum's estimate of theta
theta0.hat<-dd.est(x,y)
theta0.hat
vartheta0.hat<-dd.est(y,x)
vartheta0.hat
## mrle
m<-length(x)
n<-length(y)
N<-m+n
lambda<-m/N
phat0<-phi(N, theta0.hat, lambda)/N
mrle.sporm(x, y, theta0.hat, phat0)
# }

Run the code above in your browser using DataLab