Learn R Programming

sporm (version 1.1.1)

sporm-package: Semiparametric proportional odds rate model

Description

A rank-based empirical likelihood approach to two-sample proportional odds model and its goodness-of-fit. Let \(x_1,\ldots,x_m\) and \(y_1,\ldots,y_n\) be two independent samples from distributions \(F\) and \(G\) that satisfy $$[G(x)/\{1-G(x)\}]/[F(x)\{1-F(x)\}]=G(x)\{1-F(x)\}/[F(x)\{1-G(x)\}]=\theta$$ Function mele.theta.p returns rank-based maximum likelihood estimates of \(\theta\), \(\hat\theta\), and probability masses \(p_1,\ldots,p_N\) of \(F\) at the sorted pooled sample values \(z_1<\cdots<z_N\), \(N=m+n\).

Arguments

Details

Package: sporm
Type: Package
Version: 1.0
Date: 2011-01-01
License: GPL 2.0 or newer
LazyLoad: yes

The most important function is mrle.sporm which returns the maximum rank-based likelihood estimates the proportionality paramter \(\theta\) and the baseline distribution. Function ks.sporm is used to do the GOF test of the model assumption using a Kolmogorov-Smirnov type test statistic; confid.int.theta returns a confidence interval for \(\theta\); test.theta does the hypothesis testing for \(\theta\); Ell.Theta calculates the profile loglikelihood \(\ell(\theta)\) on interval \((\theta_1,\theta_2)\) which contains \(\hat\theta\); and plotor plot the empirical odds ratio. Functions newton.theta, dd.est and phi can be used to calculate other initials. There are few internal functions: V.theta, H.Binv, grad.hessinv, ks.stat, and elltheta. Dataset RadarTube contains the failure times (in days) of two types of radar tubes.

References

Zhong Guan and Cheng Peng (2011), "A rank-based empirical likelihood approach to two-sample proportional odds model and its goodness-of-fit", Journal of Nonparametric Statistics, to appear.